@@ -437,10 +437,7 @@ void
 on_comp_stub_selcable_btn_clicked      (GtkButton       *button,
                                         gpointer         user_data)
 {
-  GtkWidget *btn, *w = create_CableWindow();
-  btn = lookup_widget(w, "cable_accept_btn");
-  g_object_set_data(G_OBJECT(btn), "caller", GINT_TO_POINTER(SEP_STUB_VAL));
-  gtk_widget_show(w);
+  comp_stub_selcable_btn_clicked();
 }
 
 
@@ -448,10 +445,7 @@ void
 on_comp_line_selcable_btn_clicked      (GtkButton       *button,
                                         gpointer         user_data)
 {
-  GtkWidget *btn, *w = create_CableWindow();
-  btn = lookup_widget(w, "cable_accept_btn");
-  g_object_set_data(G_OBJECT(btn), "caller", GINT_TO_POINTER(SEP_LINE_VAL));
-  gtk_widget_show(w);
+  comp_line_selcable_btn_clicked();
 }
 
 
@@ -511,8 +505,7 @@ void
 on_circ_treeview_cursor_changed        (GtkTreeView     *treeview,
                                         gpointer         user_data)
 {
-  fetch_selected_element(treeview, &act_el);
-  recalculate_all(DST_SCREEN);
+  circ_treeview_cursor_changed(treeview);
 }
 
 
@@ -636,51 +629,6 @@ on_test1_activate                      (GtkMenuItem     *menuitem,
 //      Predefined cable selection window
 //=====================================================================
 
-void
-on_CableWindow_realize                 (GtkWidget       *widget,
-                                        gpointer         user_data)
-{
-  load_cable_table(widget);
-}
-
-
-void
-on_cable_view_cursor_changed           (GtkTreeView     *treeview,
-                                        gpointer         user_data)
-{
-  GtkWidget *btn = lookup_widget(GTK_WIDGET(treeview), "cable_accept_btn");
-  GtkTreeSelection *sel = gtk_tree_view_get_selection(treeview);
-  GtkTreeModel *model;
-  GtkTreeIter iter;
-  int cable;
-
-  gtk_tree_selection_get_selected(sel, &model, &iter);
-  gtk_tree_model_get(model, &iter, 7, &cable, -1);
-  g_object_set_data(G_OBJECT(btn), "cable", GINT_TO_POINTER(cable));
-}
-
-
-void
-on_cable_cancel_btn_clicked            (GtkButton       *button,
-                                        gpointer         user_data)
-{
-  gtk_widget_destroy(lookup_widget(GTK_WIDGET(button), "CableWindow"));
-}
-
-
-void
-on_cable_accept_btn_clicked            (GtkButton       *button,
-                                        gpointer         user_data)
-{
-  GtkWidget *wdw = lookup_widget(GTK_WIDGET(button), "CableWindow");
-  int which = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(button), "caller"));
-  int cable = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(button), "cable"));
-
-  show_cable_data(which, cable);
-  gtk_widget_destroy(wdw);
-}
-
-
 void
 on_loadtype_notebook_switch_page       (GtkNotebook     *notebook,
                                         GtkNotebookPage *page,
@@ -776,3 +724,26 @@ on_print1_activate                     (GtkMenuItem     *menuitem,
   print_chart(pref.last_ps_file);
 }
 
+void
+on_cable_remove_btn_clicked            (GtkButton       *button,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_cable_add_btn_clicked               (GtkButton       *button,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_cable_edit_btn_clicked              (GtkButton       *button,
+                                        gpointer         user_data)
+{
+
+}
+
