@@ -130,7 +130,7 @@ set_chart_background_bitmap(char *bgf)
 		"x", 0.0, "y", -charth/2,
 		"width", chartw, "height", charth,
 		NULL);
-  gdk_pixbuf_unref(chart_pxm);
+  g_object_unref(G_OBJECT(chart_pxm));
   gnome_canvas_set_scroll_region(chart_canvas,
 		0.0, -charth/2, chartw, charth/2);
 }
