@@ -42,91 +42,91 @@ conf_definition preftable[] = {
   //	     *def;	Default value
 
   // General
-  {CFM_W_SPBTN_INT,	"conf_prec_mhz_spbtn",		&pref.prec_mhz, 0,
-   CFM_T_INT,		"global/prec_mhz",		0, "3"},
-  {CFM_W_SPBTN_INT,	"conf_prec_imp_spbtn",		&pref.prec_imp, 0,
-   CFM_T_INT,		"global/prec_imp",		0, "3"},
-  {CFM_W_SPBTN_INT,     "conf_prec_adm_spbtn",		&pref.prec_adm, 0,
-   CFM_T_INT,           "global/prec_adm",		0, "6"},
-  {CFM_W_CBTN,          "conf_always_imp_cbtn",		&pref.always_imp, 0,
-   CFM_T_CHAR,          "global/always_imp",		0, "1"},
+  {CFM_W_SPBTN_INT,	    "conf_prec_mhz_spbtn",		    &pref.prec_mhz, 0,
+   CFM_T_INT,		    "global/prec_mhz",		        0, "3"},
+  {CFM_W_SPBTN_INT,	    "conf_prec_imp_spbtn",		    &pref.prec_imp, 0,
+   CFM_T_INT,		    "global/prec_imp",		        0, "3"},
+  {CFM_W_SPBTN_INT,     "conf_prec_adm_spbtn",		    &pref.prec_adm, 0,
+   CFM_T_INT,           "global/prec_adm",		        0, "6"},
+  {CFM_W_CBTN,          "conf_always_imp_cbtn",		    &pref.always_imp, 0,
+   CFM_T_CHAR,          "global/always_imp",		    0, "1"},
 
-  {CFM_W_ENTRY_DOUBLE,  "conf_swr_entry",		&pref.swr_circle, 2,
-   CFM_T_DOUBLE,        "global/swr_circle",		0, "2.0"},
-  {CFM_W_COLORBUTTON,   "conf_swrcircle_colbtn",	&pref.swr_color, 0,
-   CFM_T_INT,           "aspect/swr_color",		0, "-16776961"},
-  {CFM_W_CBTN,          "conf_swr_cbtn",		&pref.show_swr, 0,
-   CFM_T_CHAR,          "global/show_swr",		0, "1"},
-  {CFM_W_ENTRY_STR,     "conf_complex_entry",		&pref.complex_sfx, 0,
-   CFM_T_STR,           "global/complex_suffix",	0, "j"},
+  {CFM_W_ENTRY_DOUBLE,  "conf_swr_entry",		        &pref.swr_circle, 2,
+   CFM_T_DOUBLE,        "global/swr_circle",		    0, "2.0"},
+  {CFM_W_COLORBUTTON,   "conf_swrcircle_colbtn",	    &pref.swr_color, 0,
+   CFM_T_INT,           "aspect/swr_color",		        0, "-16776961"},
+  {CFM_W_CBTN,          "conf_swr_cbtn",		        &pref.show_swr, 0,
+   CFM_T_CHAR,          "global/show_swr",		        0, "1"},
+  {CFM_W_ENTRY_STR,     "conf_complex_entry",		    &pref.complex_sfx, 0,
+   CFM_T_STR,           "global/complex_suffix",	    0, "j"},
 
-  {CFM_W_CBTN,          "conf_g1_cbtn",			&pref.show_g1, 0,
-   CFM_T_CHAR,          "global/show_g1",		0, "1"},
-  {CFM_W_COLORBUTTON,   "conf_g1circle_colbtn",		&pref.g1_color, 0,
-   CFM_T_INT,           "aspect/g1_color",		0, "-1381126657"},
-  {CFM_W_CBTN,          "use_bitmap_cbtn",		&pref.use_bitmap, 0,
-   CFM_T_CHAR,          "global/use_bitmap",		0, "0"},
+  {CFM_W_CBTN,          "conf_g1_cbtn",			        &pref.show_g1, 0,
+   CFM_T_CHAR,          "global/show_g1",		        0, "1"},
+  {CFM_W_COLORBUTTON,   "conf_g1circle_colbtn",		    &pref.g1_color, 0,
+   CFM_T_INT,           "aspect/g1_color",		        0, "-1381126657"},
+  {CFM_W_CBTN,          "use_bitmap_cbtn",		        &pref.use_bitmap, 0,
+   CFM_T_CHAR,          "global/use_bitmap",		    0, "0"},
 
-  {CFM_W_FONTBUTTON,    "conf_cursor_font_fbtn",	&pref.cursor_font, 0,
-   CFM_T_STR,           "aspect/cursor_font",		0, "Courier New 8"}, 
-  {CFM_W_FONTBUTTON,    "conf_results_font_fbtn",	&pref.results_font, 0,
-   CFM_T_STR,           "aspect/results_font",		0, "Courier New 8"}, 
+  {CFM_W_FONTBUTTON,    "conf_cursor_font_fbtn",	    &pref.cursor_font, 0,
+   CFM_T_STR,           "aspect/cursor_font",		    0, "Courier New 8"}, 
+  {CFM_W_FONTBUTTON,    "conf_results_font_fbtn",	    &pref.results_font, 0,
+   CFM_T_STR,           "aspect/results_font",		    0, "Courier New 8"}, 
 
   // screen plot colors & sizes
 
-  {CFM_W_SPBTN_INT,     "conf_load_spbtn",		&pref.point_size[ZPT_LOAD], 0,
-   CFM_T_INT,           "aspect/load_size",		0, "8"},
-  {CFM_W_SPBTN_INT,     "conf_point_spbtn",		&pref.point_size[ZPT_INT], 0,
-   CFM_T_INT,           "aspect/point_size",		0, "6"},
-  {CFM_W_SPBTN_INT,     "conf_final_spbtn",		&pref.point_size[ZPT_FINAL], 0,
-   CFM_T_INT,           "aspect/final_size",		0, "8"},
+  {CFM_W_SPBTN_INT,     "conf_load_spbtn",		        &pref.point_size[ZPT_LOAD], 0,
+   CFM_T_INT,           "aspect/load_size",		        0, "8"},
+  {CFM_W_SPBTN_INT,     "conf_point_spbtn",		        &pref.point_size[ZPT_INT], 0,
+   CFM_T_INT,           "aspect/point_size",		    0, "6"},
+  {CFM_W_SPBTN_INT,     "conf_final_spbtn",		        &pref.point_size[ZPT_FINAL], 0,
+   CFM_T_INT,           "aspect/final_size",		    0, "8"},
 
-  {CFM_W_COLORBUTTON,   "conf_load_colbtn",		&pref.point_color[ZPT_LOAD], 0,
-   CFM_T_INT,           "aspect/load_color",		0, "0xffff00ff"},
-  {CFM_W_COLORBUTTON,   "conf_point_colbtn",		&pref.point_color[ZPT_INT], 0,
-   CFM_T_INT,           "aspect/point_color",		0, "0x00ff00ff"},
-  {CFM_W_COLORBUTTON,   "conf_final_colbtn",		&pref.point_color[ZPT_FINAL], 0,
-   CFM_T_INT,           "aspect/final_color",		0, "0xff0400ff"},
+  {CFM_W_COLORBUTTON,   "conf_load_colbtn",		        &pref.point_color[ZPT_LOAD], 0,
+   CFM_T_INT,           "aspect/load_color",		    0, "0xffff00ff"},
+  {CFM_W_COLORBUTTON,   "conf_point_colbtn",		    &pref.point_color[ZPT_INT], 0,
+   CFM_T_INT,           "aspect/point_color",		    0, "0x00ff00ff"},
+  {CFM_W_COLORBUTTON,   "conf_final_colbtn",		    &pref.point_color[ZPT_FINAL], 0,
+   CFM_T_INT,           "aspect/final_color",		    0, "0xff0400ff"},
 
-  {CFM_W_COLORBUTTON,   "conf_z_arc_colbtn",		&pref.arc_color[Z_ARC], 0,
-   CFM_T_INT,           "aspect/z_arc_color",		0, "0xff7474ff"},
-  {CFM_W_SPBTN_DOUBLE,  "conf_z_arc_spbtn",		&pref.arc_size[Z_ARC], 0,
-   CFM_T_DOUBLE,	"aspect/z_arc_width",		0, "1.0"},
+  {CFM_W_COLORBUTTON,   "conf_z_arc_colbtn",		    &pref.arc_color[Z_ARC], 0,
+   CFM_T_INT,           "aspect/z_arc_color",		    0, "0xff7474ff"},
+  {CFM_W_SPBTN_DOUBLE,  "conf_z_arc_spbtn",		        &pref.arc_size[Z_ARC], 0,
+   CFM_T_DOUBLE,	    "aspect/z_arc_width",	        0, "1.0"},
    
-  {CFM_W_COLORBUTTON,   "conf_y_arc_colbtn",		&pref.arc_color[Y_ARC], 0,
-   CFM_T_INT,           "aspect/y_arc_color",		0, "0x808080ff"},
-  {CFM_W_SPBTN_DOUBLE,  "conf_y_arc_spbtn",		&pref.arc_size[Y_ARC], 0,
-   CFM_T_DOUBLE,	"aspect/y_arc_width",		0, "1.0"},
+  {CFM_W_COLORBUTTON,   "conf_y_arc_colbtn",		    &pref.arc_color[Y_ARC], 0,
+   CFM_T_INT,           "aspect/y_arc_color",		    0, "0x808080ff"},
+  {CFM_W_SPBTN_DOUBLE,  "conf_y_arc_spbtn",		        &pref.arc_size[Y_ARC], 0,
+   CFM_T_DOUBLE,	    "aspect/y_arc_width",           0, "1.0"},
 
-  {CFM_W_COLORBUTTON,   "conf_line_arc_colbtn",		&pref.arc_color[K_ARC], 0,
-   CFM_T_INT,           "aspect/line_arc_color",	0, "0x5ece5eff"},
-  {CFM_W_SPBTN_DOUBLE,  "conf_line_arc_spbtn",		&pref.arc_size[K_ARC], 0,
-   CFM_T_DOUBLE,	"aspect/line_arc_width",	0, "1.0"},
+  {CFM_W_COLORBUTTON,   "conf_line_arc_colbtn",		    &pref.arc_color[K_ARC], 0,
+   CFM_T_INT,           "aspect/line_arc_color",	    0, "0x5ece5eff"},
+  {CFM_W_SPBTN_DOUBLE,  "conf_line_arc_spbtn",		    &pref.arc_size[K_ARC], 0,
+   CFM_T_DOUBLE,	    "aspect/line_arc_width",        0, "1.0"},
 
-  {CFM_W_COLORBUTTON,   "conf_zy_line_colbtn",		&pref.arc_color[ZY_LINE], 0,
-   CFM_T_INT,           "aspect/zy_line_color",		0, "0xa7a7a7ff"},
-  {CFM_W_SPBTN_DOUBLE,  "conf_zy_line_spbtn",		&pref.arc_size[ZY_LINE], 0,
-   CFM_T_DOUBLE,	"aspect/zy_line_width",		0, "1.0"},
+  {CFM_W_COLORBUTTON,   "conf_zy_line_colbtn",		    &pref.arc_color[ZY_LINE], 0,
+   CFM_T_INT,           "aspect/zy_line_color",		    0, "0xa7a7a7ff"},
+  {CFM_W_SPBTN_DOUBLE,  "conf_zy_line_spbtn",		    &pref.arc_size[ZY_LINE], 0,
+   CFM_T_DOUBLE,	    "aspect/zy_line_width",	        0, "1.0"},
 
-  {CFM_W_COLORBUTTON,   "conf_r_arc_colbtn",		&pref.arc_color[R_ARC], 0,
-   CFM_T_INT,           "aspect/r_arc_color",		0, "0xc0c0ffff"},
-  {CFM_W_COLORBUTTON,   "conf_r_arc_bold_colbtn",	&pref.arc_color[RB_ARC], 0,
-   CFM_T_INT,           "aspect/rb_arc_color",		0, "0x8080ffff"},
+  {CFM_W_COLORBUTTON,   "conf_r_arc_colbtn",		    &pref.arc_color[R_ARC], 0,
+   CFM_T_INT,           "aspect/r_arc_color",		    0, "0xc0c0ffff"},
+  {CFM_W_COLORBUTTON,   "conf_r_arc_bold_colbtn",	    &pref.arc_color[RB_ARC], 0,
+   CFM_T_INT,           "aspect/rb_arc_color",		    0, "0x8080ffff"},
 
-  {CFM_W_COLORBUTTON,   "conf_x_arc_colbtn",		&pref.arc_color[X_ARC], 0,
-   CFM_T_INT,           "aspect/x_arc_color",		0, "0xc0c0ffff"},
-  {CFM_W_COLORBUTTON,   "conf_x_arc_bold_colbtn",	&pref.arc_color[XB_ARC], 0,
-   CFM_T_INT,           "aspect/xb_arc_color",   	0, "0x8080ffff"},
+  {CFM_W_COLORBUTTON,   "conf_x_arc_colbtn",		    &pref.arc_color[X_ARC], 0,
+   CFM_T_INT,           "aspect/x_arc_color",		    0, "0xc0c0ffff"},
+  {CFM_W_COLORBUTTON,   "conf_x_arc_bold_colbtn",	    &pref.arc_color[XB_ARC], 0,
+   CFM_T_INT,           "aspect/xb_arc_color",   	    0, "0x8080ffff"},
 
-  {CFM_W_COLORBUTTON,	"conf_g1_colbtn",		&pref.g1_color, 0,
-   CFM_T_INT,           "aspect/g1_color",		0, "0x808080ff"},
-  {CFM_W_COLORBUTTON,   "conf_swr_colbtn",		&pref.swr_color, 0,
-   CFM_T_INT,           "aspect/swr_color",		0, "0xff8080ff"},
+  {CFM_W_COLORBUTTON,	"conf_g1_colbtn",               &pref.g1_color, 0,
+   CFM_T_INT,           "aspect/g1_color",              0, "0x808080ff"},
+  {CFM_W_COLORBUTTON,   "conf_swr_colbtn",              &pref.swr_color, 0,
+   CFM_T_INT,           "aspect/swr_color",             0, "0xff8080ff"},
 
   // [29] Screen bitmap background
-  {CFM_W_ENTRY_STR,     "conf_chartbg_entry",            &pref.chart, 0,
+  {CFM_W_ENTRY_STR,     "conf_chartbg_entry",           &pref.chart, 0,
    CFM_T_STR,           "chart/chartbg",                0,
-			PACKAGE_DATA_DIR"/pixmaps/linsmith/smith4.png"},
+                        PACKAGE_DATA_DIR"/pixmaps/linsmith/smith4.png"},
   {CFM_W_ENTRY_DOUBLE,  "conf_radius_entry",            &pref.chartradius, 1,
    CFM_T_DOUBLE,        "chart/radius",                 0,      "211"},
   {CFM_W_ENTRY_DOUBLE,  "conf_xoffs_entry",             &pref.x_offs, 1,
@@ -137,8 +137,8 @@ conf_definition preftable[] = {
   // [33] Screen vector background
   {CFM_W_COLORBUTTON,   "conf_vecbg_colbtn",	        &pref.vec_background, 0,
    CFM_T_INT,           "aspect/vecbg_color",           0,      "0xf0ffffff"},
-  {CFM_W_ENTRY_INT,	"conf_vecbg_size_entry",        &pref.vec_bg_radius, 0,
-   CFM_T_INT,		"aspect/vecbg_size",            0,      "250"},
+  {CFM_W_ENTRY_INT,	    "conf_vecbg_size_entry",        &pref.vec_bg_radius, 0,
+   CFM_T_INT,		    "aspect/vecbg_size",            0,      "250"},
 
   {CFM_W_FONTBUTTON,    "conf_font_fpick",              &pref.vec_font_name, 0,
    CFM_T_STR,           "aspect/font",                  0,      "Helvetica 8"},
@@ -177,14 +177,14 @@ conf_definition preftable[] = {
 
   // X arcs - bold
   {CFM_W_COLORBUTTON,   "prt_x_arc_bold_colbtn",        &pref.prt_arc_color[XB_ARC],	0,
-   CFM_T_INT,           "print/bgarc_bold_color_x",	0,      "0xff6060ff"},
+   CFM_T_INT,           "print/bgarc_bold_color_x",	    0,      "0xff6060ff"},
   {CFM_W_SPBTN_DOUBLE,  "prt_x_arc_bold_spbtn",         &pref.prt_arc_size[XB_ARC],	0,
-   CFM_T_DOUBLE,        "print/bgarc_bold_size_x",	0,      "0.2"},
+   CFM_T_DOUBLE,        "print/bgarc_bold_size_x",	    0,      "0.2"},
 
-  {CFM_W_COLORBUTTON,	"prt_g1_colbtn",		&pref.prt_g1_color, 0,
-   CFM_T_INT,           "print/g1_color",		0,      "0x808080ff"},
-  {CFM_W_COLORBUTTON,   "prt_swr_colbtn",		&pref.prt_swr_color, 0,
-   CFM_T_INT,           "print/swr_color",		0,      "0xff7a7aff"},
+  {CFM_W_COLORBUTTON,	"prt_g1_colbtn",		        &pref.prt_g1_color, 0,
+   CFM_T_INT,           "print/g1_color",		        0,      "0x808080ff"},
+  {CFM_W_COLORBUTTON,   "prt_swr_colbtn",		        &pref.prt_swr_color, 0,
+   CFM_T_INT,           "print/swr_color",		        0,      "0xff7a7aff"},
 
   // Actual (print) plot properties - load, intermediate, source points
 
@@ -274,6 +274,9 @@ conf_definition preftable[] = {
    CFM_T_STR,		"remote/inpipe",		0,	"/tmp/linsmith.in"},
   {CFM_W_ENTRY_INT,	"confrem_timeout_entry",	&pref.rem_timeout,	0,
    CFM_T_INT,		"remote/timeout",		0,	"2000"},
+  {CFM_W_ENTRY_STR,	"confrem_serial_port_entry",    &pref.rem_serial_port,	0,
+   CFM_T_STR,		"remote/serial_port",		0,	"/dev/ttyS1"},
+   
 
   // Noisebridge tab:
   {CFM_W_ENTRY_DOUBLE,  "conf_nb_offs_entry",           &pref.nb_offset,        2,
@@ -296,8 +299,8 @@ conf_definition preftable[] = {
    CFM_T_STR,           "files/last_s2p_file",          0,      ""},
 
   // File tab: CSV separator character
-  {CFM_W_ENTRY_STR,	"conf_csv_sep_entry", 	        &pref.csv_sep,          0,
-   CFM_T_STR,		"files/csv_sep",	        0,      ","},
+  {CFM_W_ENTRY_STR,	    "conf_csv_sep_entry", 	&pref.csv_sep,          0,
+   CFM_T_STR,		    "files/csv_sep",	        0,      ","},
 
   {CFM_W_LAST}
 };
