@@ -30,6 +30,7 @@
 
 #include "support.h"
 #include "callbacks.h"
+#include "printer.h"
 #include "global.h"
 #include "main.h"
 #include "load.h"
@@ -76,7 +77,7 @@ enable_load_rx_buttons(int action)
 
   if (action == LOADLIST_UPDATED ||
       action == LOADLIST_REMOVED)
-    recalculate_all();
+    recalculate_all(DST_SCREEN);
 }
 
 
