@@ -23,11 +23,6 @@
 #include <math.h>
 #include <libxml/tree.h>
 
-enum   {SEP_IND_VAL, SEP_CAP_VAL,
-	SEP_STUB_VAL, SEP_STUB_Z0, 
-	SEP_LINE_VAL, SEP_LINE_Z0,
-	SEP_XFORM_VAL};
-
 //	Import/load value dialog:
 enum   {LSTDLG_APPEND,		// append new values
 	LSTDLG_CLEAR,		// clear list first
@@ -39,9 +34,6 @@ int		list_not_empty_dialog(char *msg);
 void            show_about(void);
 gboolean	run_filedialog(char *title, char *fn, gboolean openfile, ...);
 
-void		load_cable_table(GtkWidget *cmb);
-void		show_cable_data(int which, int c);
-
 void		initialize_MainWindow(void);
 int		xml_file_open(xmlDocPtr *doc, const char *fname, char *title);
 
